@@ -37,6 +37,8 @@ public:
     ConfigerPrivate(Configer *parent);
     static UserPreferencePointer defaultSearcher();
     static UserPreferencePointer fileSearcher();
+    static UserPreferencePointer tailerData();
+    static UserPreferencePointer blacklist();
     bool updateConfig1(QSettings *);
 private:
     Configer *q;
