@@ -34,7 +34,7 @@ public:
     explicit MatchController(QObject *parent = nullptr);
     ~MatchController();
 
-    void onMissionIdChanged(const QString &missionId);
+    void onMissionChanged(const QString &missionId, const QString &missionContent);
 
 signals:
     void matchedResult(const GrandSearch::MatchedItemMap &);
