@@ -32,6 +32,14 @@
         <translation>Time modified:</translation>
     </message>
 </context>
+<context>
+    <name>CustomWidget</name>
+    <message>
+        <location filename="../src/grand-search/gui/searchconfig/customwidget.cpp" line="38"/>
+        <source>Custom search</source>
+        <translation>Custom search</translation>
+    </message>
+</context>
 <context>
     <name>DdeGrandSearchDockPlugin</name>
     <message>
@@ -111,7 +119,7 @@
 <context>
     <name>GroupWidget</name>
     <message>
-        <location filename="../src/grand-search/gui/exhibition/matchresult/groupwidget.cpp" line="261"/>
+        <location filename="../src/grand-search/gui/exhibition/matchresult/groupwidget.cpp" line="254"/>
         <source>More</source>
         <translation>More</translation>
     </message>
@@ -147,7 +155,7 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../src/grand-search/gui/mainwindow.cpp" line="217"/>
+        <location filename="../src/grand-search/gui/mainwindow.cpp" line="224"/>
         <source>No search results</source>
         <translation>No search results</translation>
     </message>
@@ -155,7 +163,7 @@
 <context>
     <name>MatchWidget</name>
     <message>
-        <location filename="../src/grand-search/gui/exhibition/matchresult/matchwidget.cpp" line="89"/>
+        <location filename="../src/grand-search/gui/exhibition/matchresult/matchwidget.cpp" line="88"/>
         <source>Search for &quot;%1&quot;</source>
         <translation>Search for &quot;%1&quot;</translation>
     </message>
@@ -202,46 +210,51 @@
     <name>QObject</name>
     <message>
         <location filename="../src/grand-search/gui/datadefine.h" line="41"/>
+        <source>Best match</source>
+        <translation>Best match</translation>
+    </message>
+    <message>
+        <location filename="../src/grand-search/gui/datadefine.h" line="42"/>
         <source>Applications</source>
         <translation>Applications</translation>
     </message>
     <message>
-        <location filename="../src/grand-search/gui/datadefine.h" line="42"/>
+        <location filename="../src/grand-search/gui/datadefine.h" line="43"/>
         <source>Settings</source>
         <translation>Settings</translation>
     </message>
     <message>
-        <location filename="../src/grand-search/gui/datadefine.h" line="43"/>
+        <location filename="../src/grand-search/gui/datadefine.h" line="44"/>
         <source>Videos</source>
         <translation>Videos</translation>
     </message>
     <message>
-        <location filename="../src/grand-search/gui/datadefine.h" line="44"/>
+        <location filename="../src/grand-search/gui/datadefine.h" line="45"/>
         <source>Music</source>
         <translation>Music</translation>
     </message>
     <message>
-        <location filename="../src/grand-search/gui/datadefine.h" line="45"/>
+        <location filename="../src/grand-search/gui/datadefine.h" line="46"/>
         <source>Pictures</source>
         <translation>Pictures</translation>
     </message>
     <message>
-        <location filename="../src/grand-search/gui/datadefine.h" line="46"/>
+        <location filename="../src/grand-search/gui/datadefine.h" line="47"/>
         <source>Documents</source>
         <translation>Documents</translation>
     </message>
     <message>
-        <location filename="../src/grand-search/gui/datadefine.h" line="47"/>
+        <location filename="../src/grand-search/gui/datadefine.h" line="48"/>
         <source>Folders</source>
         <translation>Folders</translation>
     </message>
     <message>
-        <location filename="../src/grand-search/gui/datadefine.h" line="48"/>
+        <location filename="../src/grand-search/gui/datadefine.h" line="49"/>
         <source>Files</source>
         <translation>Files</translation>
     </message>
     <message>
-        <location filename="../src/grand-search/gui/datadefine.h" line="49"/>
+        <location filename="../src/grand-search/gui/datadefine.h" line="50"/>
         <source>Web</source>
         <translation>Web</translation>
     </message>
@@ -275,6 +288,11 @@
         <source>Time modified:</source>
         <translation>Time modified:</translation>
     </message>
+    <message>
+        <location filename="../src/grand-search-daemon/searcher/file/filesearchutils.cpp" line="215"/>
+        <source>modified</source>
+        <translation>modified</translation>
+    </message>
 </context>
 <context>
     <name>ScopeWidget</name>
@@ -284,4 +302,27 @@
         <translation>Search contents</translation>
     </message>
 </context>
+<context>
+    <name>TailerWidget</name>
+    <message>
+        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="33"/>
+        <source>Tailer settings</source>
+        <translation>Tailer settings</translation>
+    </message>
+    <message>
+        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="42"/>
+        <source>It is displayed at the end of search results for better identification and distinction of items with duplicate names.</source>
+        <translation>It is displayed at the end of search results for better identification and distinction of items with duplicate names.</translation>
+    </message>
+    <message>
+        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="50"/>
+        <source>Parent directory</source>
+        <translation>Parent directory</translation>
+    </message>
+    <message>
+        <location filename="../src/grand-search/gui/searchconfig/tailerwidget.cpp" line="52"/>
+        <source>Time modified</source>
+        <translation>Time modified</translation>
+    </message>
+</context>
 </TS>
\ No newline at end of file
